General
-----

* Add `_` prefix to getters and setters
* Migrate to Github issue tracker

Linode
-----

* `linode.config.delete`
* Make clear single-user-mode setter
* Add Linode class attributes for `status` attribute (up, down, ?)

Nodebalacer
-----

Implement all Nodebalancer functionality
